@@ -38,6 +38,7 @@ modules = [
     "exhentai",
     "fallenangels",
     "fanbox",
+    "fanleaks",
     "fantia",
     "fapello",
     "fapachi",
@@ -135,6 +136,7 @@ modules = [
     "speakerdeck",
     "subscribestar",
     "tapas",
+    "tcbscans",
     "telegraph",
     "toyhouse",
     "tsumino",
