@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2022 Mike Fährmann
+# Copyright 2022-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -59,7 +59,7 @@ class PoipikuExtractor(Extractor):
                     "//img.", "//img-org.", 1)
                 yield Message.Url, url, text.nameext_from_url(url, post)
 
-            if not extr('> show all', '<'):
+            if not extr(' show all(+', '<'):
                 continue
 
             url = self.root + "/f/ShowAppendFileF.jsp"
@@ -79,6 +79,9 @@ class PoipikuExtractor(Extractor):
             page = self.request(
                 url, method="POST", headers=headers, data=data).json()["html"]
 
+            if page.startswith("You need to"):
+                self.log.warning("'%s'", page)
+
             for thumb in text.extract_iter(
                     page, 'class="IllustItemThumbImg" src="', '"'):
                 post["num"] += 1
@@ -162,6 +165,21 @@ class PoipikuPostExtractor(PoipikuExtractor):
                 "user_name": "wadahito",
             },
         }),
+        # different warning button style
+        ("https://poipiku.com/3572553/5776587.html", {
+            "pattern": r"https://img-org\.poipiku.com/user_img\d+/003572553"
+                       r"/005776587_(\d+_)?\w+\.jpeg$",
+            "count": 3,
+            "keyword": {
+                "count": "3",
+                "description": "ORANGE OASISボスネタバレ",
+                "num": int,
+                "post_category": "SPOILER",
+                "post_id": "5776587",
+                "user_id": "3572553",
+                "user_name": "nagakun",
+            },
+        }),
     )
 
     def __init__(self, match):
